@@ -5,7 +5,7 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
     
   # check class
   if (!(class(object)[1] == "glm")) {
-    stop("Restriktor ERROR: object must be of class glm.")
+    stop("restriktor ERROR: object must be of class glm.")
   }
   # standard error methods
   if (se == "default") {
@@ -15,11 +15,11 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
   }
   if (!(se %in% c("none","standard","const","boot.model.based","boot.standard",
                   "HC","HC0","HC1","HC2","HC3","HC4","HC4m","HC5"))) {
-    stop("Restriktor ERROR: standard error method ", sQuote(se), " unknown.")
+    stop("restriktor ERROR: standard error method ", sQuote(se), " unknown.")
   }
   # check method to compute chi-square-bar weights
   if (!(mix_weights %in% c("pmvnorm", "boot", "none"))) {
-    stop("Restriktor ERROR: ", sQuote(mix_weights), " method unknown. Choose from \"pmvnorm\", \"boot\", or \"none\"")
+    stop("restriktor ERROR: ", sQuote(mix_weights), " method unknown. Choose from \"pmvnorm\", \"boot\", or \"none\"")
   }
   
   # timing
@@ -122,7 +122,7 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
   
   ## some checks
   if(ncol(Amat) != length(b.unrestr)) {
-    stop(paste("Restriktor ERROR: length coefficients and the number of",
+    stop(paste("restriktor ERROR: length coefficients and the number of",
          "columns constraints-matrix must be identical"))
   }
   
@@ -286,7 +286,7 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
       }
     } else if (se == "boot.model.based") {
       if (attr(object$terms, "intercept") && any(Amat[,1] == 1)) {
-          stop(paste("Restriktor ERROR: no restrictions on intercept possible",
+          stop(paste("restriktor ERROR: no restrictions on intercept possible",
                "for 'se = boot.model.based' bootstrap method."))
       }
       OUT$bootout <- con_boot_lm(object      = object, 
@@ -338,7 +338,7 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
     if (mix_weights == "pmvnorm") {
       if (RREF$rank < nrow(PT_Amat) && RREF$rank != 0L) {
         messages$mix_weights_rank <- paste(
-          "Restriktor message: Since the constraint matrix is not full row-rank, the level probabilities", 
+          "restriktor Message: Since the constraint matrix is not full row-rank, the level probabilities", 
           "are calculated using mix_weights = \"boot\" (the default is mix_weights = \"pmvnorm\").",
           "For more information see ?restriktor.\n"
         )
@@ -353,7 +353,7 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
     if (mix_weights == "pmvnorm") {
       if (rAmat$rank < nrow(Amat) && rAmat$rank != 0L) {
         messages$mix_weights_rank <- paste(
-          "Restriktor message: Since the constraint matrix is not full row-rank, the level probabilities", 
+          "restriktor Message: Since the constraint matrix is not full row-rank, the level probabilities", 
           "are calculated using mix_weights = \"boot\" (the default is mix_weights = \"pmvnorm\").",
           "For more information see ?restriktor.\n"
         )
@@ -378,4 +378,4 @@ conGLM.glm <- function(object, constraints = NULL, se = "standard",
   class(OUT) <- c("restriktor", "conGLM")
   
   OUT
-}
\ No newline at end of file
+}
