@@ -5,7 +5,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   
   # check class
   if (!(class(object)[1] %in% c("lm", "aov"))) {
-    stop("Restriktor ERROR: object must be of class lm.")
+    stop("restriktor ERROR: object must be of class lm.")
   }
   # standard error methods
   if (se == "default") {
@@ -15,11 +15,11 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   }
   if (!(se %in% c("none","standard","const","boot.model.based","boot.standard",
                   "HC","HC0","HC1","HC2","HC3","HC4","HC4m","HC5"))) {
-    stop("Restriktor ERROR: standard error method ", sQuote(se), " unknown.", call. = FALSE)
+    stop("restriktor ERROR: standard error method ", sQuote(se), " unknown.", call. = FALSE)
   }
   # check method to compute chi-square-bar weights
   if (!(mix_weights %in% c("pmvnorm", "boot", "none"))) {
-    stop("Restriktor ERROR: ", sQuote(mix_weights), " method unknown. Choose from \"pmvnorm\", \"boot\", or \"none\".", call. = FALSE)
+    stop("restriktor ERROR: ", sQuote(mix_weights), " method unknown. Choose from \"pmvnorm\", \"boot\", or \"none\".", call. = FALSE)
   }
   
   # timing
@@ -118,7 +118,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   
   ## some checks
   if (ncol(Amat) != length(b.unrestr)) {
-    stop(paste("Restriktor ERROR: length coefficients and the number of",
+    stop(paste("restriktor ERROR: length coefficients and the number of",
          "columns constraints-matrix must be identical"), call. = FALSE)
   }
   
@@ -282,7 +282,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
       }
     } else if (se == "boot.model.based") {
       if (attr(object$terms, "intercept") && any(Amat[, 1] == 1)) {
-          stop("Restriktor ERROR: no restrictions on intercept possible",
+          stop("restriktor ERROR: no restrictions on intercept possible",
                " for 'se = boot.model.based' bootstrap method.", call. = FALSE)
       }
       
@@ -344,7 +344,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
     if (mix_weights == "pmvnorm") {
       if (RREF$rank < nrow(PT_Amat) && RREF$rank != 0L) {
         messages$mix_weights_rank <- paste(
-          "Restriktor message: Since the constraint matrix is not full row-rank, the level probabilities", 
+          "restriktor Message: Since the constraint matrix is not full row-rank, the level probabilities", 
           "are calculated using mix_weights = \"boot\" (the default is mix_weights = \"pmvnorm\").",
           "For more information see ?restriktor.\n"
         )
@@ -358,7 +358,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
     if (mix_weights == "pmvnorm") {
       if (rAmat$rank < nrow(Amat) && rAmat$rank != 0L) {
         messages$mix_weights_rank <- paste(
-          "Restriktor message: Since the constraint matrix is not full row-rank, the level probabilities", 
+          "restriktor Message: Since the constraint matrix is not full row-rank, the level probabilities", 
           "are calculated using mix_weights = \"boot\" (the default is mix_weights = \"pmvnorm\").",
           "For more information see ?restriktor.\n"
         )
@@ -384,4 +384,4 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   class(OUT) <- c("restriktor", "conLM")
     
   OUT
-}
\ No newline at end of file
+}
