@@ -34,7 +34,7 @@ EM <- function(object, emControl = list(), auxiliary = c(), ...) {
     #print(auxiliary)
     
     if (!is.list(emControl)) {
-      stop("Restriktor ERROR: emControl must be a named list.") 
+      stop("restriktor ERROR: emControl must be a named list.") 
     }
     
     # get original data set with missings
@@ -379,7 +379,7 @@ two_stage_matrices <- function(object, auxiliary = c(), emControl = list(), ...)
   sat_vnames_dup <- sat_vnames[duplicated(sat_vnames)]
   
   if (length(sat_vnames_dup) > 0L) {
-    stop("Restriktor ERROR: duplicated variable name(s) found: ", sQuote(sat_vnames_dup))
+    stop("restriktor ERROR: duplicated variable name(s) found: ", sQuote(sat_vnames_dup))
   }
   
   covstruc <- outer(sat_vnames, sat_vnames, function(x, y) paste(x, "~~", y))
