@@ -35,29 +35,29 @@ compute_complement_likelihood <- function(model.org, VCOV,
     ll <- vector("list", length(nr))
     betas <- vector("list", length(nr))
     if (meq > 0L) { nr <- nr[-c(0:meq)] }
-      for (l in seq_len(length(nr))) {
-        idx <- c(nr[l], nr[-l])
-        Amatx <- Amat[idx, , drop = FALSE]
-        if (type %in% c("goric", "goricc")) {          
-          Hc.restr <- restriktor(model.org, constraints = Amatx, 
-                                 neq = 1, rhs = bvec[idx], 
-                                 mix_weights = "none", se = "none")
-          betas[[l]] <- coef(Hc.restr)
-          ll[[l]]    <- logLik(Hc.restr)
-        } else if (type %in% c("gorica", "goricac")) {
-          ldots$mix_weights <- "none"
-          CALL.restr <- append(list(object      = b.unrestr,
-                                    constraints = Amatx,
-                                    rhs         = bvec[idx],
-                                    neq         = 1,
-                                    VCOV        = VCOV),
-                               ldots)
-          Hc.restr   <- do.call("con_gorica_est", CALL.restr) 
-          betas[[l]] <- Hc.restr$b.restr
-          ll[[l]]    <- dmvnorm(c(b.unrestr - Hc.restr$b.restr), 
-                                sigma = VCOV, log = TRUE)            
-        }
+    for (l in seq_len(length(nr))) {
+      idx <- c(nr[l], nr[-l])
+      Amatx <- Amat[idx, , drop = FALSE]
+      if (type %in% c("goric", "goricc")) {          
+        Hc.restr <- restriktor(model.org, constraints = Amatx, 
+                               neq = 1, rhs = bvec[idx], 
+                               mix_weights = "none", se = "none")
+        betas[[l]] <- coef(Hc.restr)
+        ll[[l]]    <- logLik(Hc.restr)
+      } else if (type %in% c("gorica", "goricac")) {
+        ldots$mix_weights <- "none"
+        CALL.restr <- append(list(object      = b.unrestr,
+                                  constraints = Amatx,
+                                  rhs         = bvec[idx],
+                                  neq         = 1,
+                                  VCOV        = VCOV),
+                             ldots)
+        Hc.restr   <- do.call("con_gorica_est", CALL.restr) 
+        betas[[l]] <- Hc.restr$b.restr
+        ll[[l]]    <- dmvnorm(c(b.unrestr - Hc.restr$b.restr), 
+                              sigma = VCOV, log = TRUE) 
       }
+    }
     if (debug) {
       cat("log-likelihood value =", ll[[l]], "\n")
     }
@@ -77,9 +77,9 @@ compute_complement_likelihood <- function(model.org, VCOV,
       cat("log-likelihood_c value =", llc, "\n")
     }
   } else if (all(c(Amat) == 0L)) {
-    stop("Restriktor ERROR: no complement exists for an unconstrained hypothesis.")
+    stop("restriktor ERROR: no complement exists for an unconstrained hypothesis.")
   } else {
-    stop("Restriktor ERROR: you might have found a bug, please contact me at: info@restriktor.org!")
+    stop("restriktor ERROR: you might have found a bug, please contact me at: info@restriktor.org!")
   }
   
   return(list(llc = llc, betasc = betasc))
