@@ -5,7 +5,9 @@
     packageStartupMessage("Please report any bugs to info@restriktor.org")
 }
 
-utils::globalVariables(c("Group", "Value", "green", "reset", 
+utils::globalVariables(c("green", "reset", "Value", 
                          "Group_hypo_comparison", "Group_pop_values", 
-                         "sample_value", "x", "y", "percentile_value",
-                         "percentile_label"))
\ No newline at end of file
+                         "sample_value", "percentile_value",
+                         "percentile_label", "Group", "OverallGoric",
+                         "GORICA_weight_m"
+                         ))
\ No newline at end of file
